import 'package:auto_route/auto_route.dart';
import 'package:cpt_main/router/page/main_page_router.dart';
import 'package:cs_resources/generated/l10n.dart';
import 'package:cs_resources/theme/app_colors_theme.dart';
import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';
import 'package:router/componentRouter/component_service_manager.dart';
import 'package:router/ext/auto_router_extensions.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:widgets/ext/ex_widget.dart';
import 'package:widgets/load_state_layout.dart';
import 'package:widgets/my_appbar.dart';
import 'package:widgets/widget_export.dart';

import 'item_list_news.dart';
import 'home_property_news_view_model.dart';

@RoutePage()
class HomePropertyNewsPage extends HookConsumerWidget {
  static void startInstance({BuildContext? context}) {
    if (context != null) {
      context.router.push(const HomePropertyNewsPageRoute());
    } else {
      appRouter.push(const HomePropertyNewsPageRoute());
    }
  }

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final viewModel = ref.read(homePropertyNewsViewModelProvider.notifier);
    final state = ref.watch(homePropertyNewsViewModelProvider);

    useEffect(() {
      // 组件挂载时执行 - 执行接口请求
      Future.microtask(() => viewModel.fetchList());
      return () {
        // 组件卸载时执行
      };
    }, []);

    return Scaffold(
      appBar: MyAppBar.appBar(context, S.current.property_news, backgroundColor: context.appColors.backgroundWhite),
      backgroundColor: context.appColors.backgroundDark,
      body: Container(
        width: double.infinity,
        height: double.infinity,
        child: EasyRefresh(
          controller: viewModel.refreshController,
          onRefresh: viewModel.onRefresh,
          onLoad: viewModel.loadMore,
          child: LoadStateLayout(
            state: state.loadingState,
            errorMessage: state.errorMessage,
            errorRetry: () {
              viewModel.retryRequest();
            },
            successSliverWidget: [
              SliverList(
                  delegate: SliverChildBuilderDelegate(
                (context, index) {
                  return ListNewsItem(index: index, item: state.datas[index]).onTap(() {
                    //路由跳转到Property模块的新闻详情页面
                    ComponentServiceManager().propertyService.startPropertyNewsDetailPage(state.datas[index].id ?? 0);
                  });
                },
                childCount: state.datas.length,
              ))
            ],
          ),
        ).marginOnly(top: 10, bottom: 5),
      ),
    );
  }
}
